{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {},
   "outputs": [],
   "source": [
    "import re\n",
    "import sys\n",
    "from urllib.request import urlopen"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [],
   "source": [
    "f = urlopen('http://www.hanbit.co.kr/store/books/full_book_list.html')\n",
    "# bytes 자료형의 응답 본문을 일단 변수에 저장\n",
    "bytes_content = f.read()  "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [],
   "source": [
    "# charset은 HTML의 앞부분에 적혀 있는 경우가 많으므로\n",
    "# 응답 본문의 앞부분 1024바이트를 ASCII 문자로 디코딩\n",
    "# ASCII 범위 이위의 문자는 U+FFFD(REPLACEMENT CHARACTER)로 변환되어 예외가 발생하지 않음\n",
    "scanned_text = bytes_content[:1024].decode('ascii', errors='replace')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {},
   "outputs": [],
   "source": [
    "# 디코딩한 문자열에서 정규 표현식으로 charset 값을 추출\n",
    "match = re.search(r'charset=[\"\\']?([\\w-]+)', scanned_text)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'utf-8'"
      ]
     },
     "execution_count": 15,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "match.group(1)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {},
   "outputs": [],
   "source": [
    "if match:\n",
    "    encoding = match.group(1)\n",
    "else:\n",
    "    # charset이 명시돼 있지 않으면 UTF-8을 사용\n",
    "    encoding = 'utf-8'"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "encoding: utf-8\n"
     ]
    }
   ],
   "source": [
    "# 추출한 인코딩을 표준 오류에 출력\n",
    "print('encoding:', encoding, file=sys.stderr)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {
    "scrolled": true
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "<!DOCTYPE html>\n",
      "<html lang=\"ko\">\n",
      "<head>\n",
      "<!--[if lte IE 8]>\n",
      "<script>\n",
      "  location.replace('/support/explorer_upgrade.html');\n",
      "</script>\n",
      "<![endif]-->\n",
      "<meta charset=\"utf-8\"/>\n",
      "<title>한빛출판네트워크</title>\n",
      "<link rel=\"shortcut icon\" href=\"https://www.hanbit.co.kr/images/common/hanbit.ico\"> \n",
      "<meta http-equiv=\"X-UA-Compatible\" content=\"IE=Edge\" />\n",
      "<meta property=\"og:type\" content=\"website\"/>\n",
      "<meta property=\"og:title\" content=\"한빛출판네트워크\"/>\n",
      "<meta property=\"og:description\" content=\"출판사, IT전문서, 대학교재, 경제경영, 어린이/유아, MAKE, 실용/여행, 전자책, 인터넷 강의\"/>\n",
      "<meta property=\"og:image\" content=\"https://www.hanbit.co.kr/images/hanbitpubnet_logo.jpg\" />\n",
      "<meta property=\"og:url\" content=\"https://www.hanbit.co.kr/store/books/full_book_list.html\"/>\n",
      "<link rel=\"canonical\" href=\"https://www.hanbit.co.kr/store/books/full_book_list.html\" />\n",
      "<meta name=\"keywords\" content=\"책,전자책,ebook,출판사,동영상,콘텐츠,강의,자격증,대학교재\" />\n",
      "<meta name=\"description\" content=\"출판사, IT전문서, 대학교재, 경제경영, 어린이/유아, MAKE, 실용/여행, 전자책, 인터넷 강의\" />\n",
      "<meta name=\"viewport\" content=\"width=device-width,initial-scale=1.0,minimum-scale=1.0,maximum-scale=1.0\">\n",
      "<meta name=\"viewport\" content=\"width=1260\">\n",
      "<meta name=\"apple-mobile-web-app-capable\" content=\"yes\" />\n",
      "<meta name=\"naver-site-verification\" content=\"01c29ed1852aecca7a48ac0c3e0869627bc512d8\"/>\n",
      "<!-- <meta name=\"naver-site-verification\" content=\"823ff8b8e7e3eb396c310703c2bbd731f48c1d9b\"/> -->\n",
      "<link rel=\"stylesheet\" href=\"/css/common.css?20190625102532\" />\n",
      "<link href=\"/css/hover.css\" rel=\"stylesheet\" media=\"all\">\n",
      "<link rel=\"stylesheet\" href=\"/js/jquery.raty.css\" />\n",
      "<script type=\"text/javascript\" src=\"/js/jquery-latest.js\"></script>\n",
      "<script type=\"text/javascript\" src=\"/js/jquery-ui.js\"></script>\n",
      "<script type=\"text/javascript\" src=\"/js/jquery.event.drag-1.5.min.js\"></script>\n",
      "<script type=\"text/javascript\" src=\"/js/jquery.touchSlider.js\"></script>\n",
      "<script type=\"text/javascript\" src=\"/js/jquery.raty.js\"></script>\n",
      "<script type=\"text/javascript\" src=\"/js/main.js\"></script>\n",
      "<script type=\"text/javascript\" src=\"/lib/cheditor/cheditor.js\"></script>\n",
      "<script type=\"text/javascript\" src=\"/js/jquery.ui.datepicker-ko.js\"></script>\n",
      "<script type=\"text/javascript\" src=\"/js/engine.js\"></script>\n",
      "<script type=\"text/javascript\" src=\"/js/vue.js\"></script>\n",
      "\n",
      "<!-- Google Analytics -->\n",
      "<script>\n",
      "(function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){\n",
      "(i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),\n",
      "m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)\n",
      "})(window,document,'script','//www.google-analytics.com/analytics.js','ga');\n",
      "ga('create', 'UA-47080738-1', 'hanbit.co.kr');\n",
      "ga('require', 'linkid', 'linkid.js');\n",
      "ga('send', 'pageview');\n",
      "</script>\n",
      "<!-- Google Analytics -->\n",
      "\n",
      "<!-- Facebook Pixel Code -->\n",
      "<script>\n",
      "  !function(f,b,e,v,n,t,s)\n",
      "  {if(f.fbq)return;n=f.fbq=function(){n.callMethod?\n",
      "  n.callMethod.apply(n,arguments):n.queue.push(arguments)};\n",
      "  if(!f._fbq)f._fbq=n;n.push=n;n.loaded=!0;n.version='2.0';\n",
      "  n.queue=[];t=b.createElement(e);t.async=!0;\n",
      "  t.src=v;s=b.getElementsByTagName(e)[0];\n",
      "  s.parentNode.insertBefore(t,s)}(window, document,'script',\n",
      "  'https://connect.facebook.net/en_US/fbevents.js');\n",
      "  fbq('init', '406459623338891');\n",
      "  fbq('track', 'PageView');\n",
      "</script>\n",
      "<noscript><img height=\"1\" width=\"1\" style=\"display:none\"\n",
      "  src=\"https://www.facebook.com/tr?id=406459623338891&ev=PageView&noscript=1\"\n",
      "/></noscript>\n",
      "<!-- End Facebook Pixel Code -->\n",
      "\n",
      "<!-- Kakao Pixel Code -->\n",
      "<script type=\"text/javascript\" charset=\"UTF-8\" src=\"//t1.daumcdn.net/adfit/static/kp.js\"></script>\n",
      "<script type=\"text/javascript\">\n",
      "  kakaoPixel('3011392806152551233').pageView();\n",
      "</script>\n",
      "<!-- //Kakao Pixel Code -->\n",
      "</head>\n",
      "<body>\n",
      "<!-- Google Tag Manager (noscript) -->\n",
      "<noscript><iframe src=\"https://www.googletagmanager.com/ns.html?id=GTM-W9D5PM3\"\n",
      "height=\"0\" width=\"0\" style=\"display:none;visibility:hidden\"></iframe></noscript>\n",
      "<!-- End Google Tag Manager (noscript) -->\n",
      "<link rel=\"stylesheet\" href=\"/css/layout-hanbit.css?20191130\" />\n",
      "<link rel=\"stylesheet\" href=\"/css/layout-member.css\" />\n",
      "<link rel=\"stylesheet\" href=\"/css/layout-network.css\" />\n",
      "<link rel=\"stylesheet\" href=\"/css/layout-store.css\" />\n",
      "<link rel=\"stylesheet\" href=\"/css/layout-myhanbit.css\" />\n",
      "<link rel=\"stylesheet\" href=\"/css/layout-event.css\" />\n",
      "<!-- 메뉴 바로가기 -->\n",
      "<div id=\"quick_skip_menu\">\n",
      "  <a href=\"#gnb\" onclick=\"document.getElementById('gnb').tabIndex = -1;document.getElementById('gnb').focus();return false;\"><span>메뉴 바로가기</span></a>\n",
      "  <a href=\"#top_search\" onclick=\"view_hover('main_search_area','','show'), document.getElementById('top_search').tabIndex = -1;document.getElementById('top_search').focus();return false;\"><span>검색 및 카테고리 바로가기</span></a>\n",
      "    <a href=\"#container\" onclick=\"document.getElementById('container').tabIndex = -1;document.getElementById('container').focus();return false;\"><span>본문 바로가기</span></a>\n",
      "  </div>\n",
      "<!-- //메뉴 바로가기 -->\n",
      "\n",
      "<!-- header -->\n",
      "<header>\n",
      "  <!-- top menu -->\n",
      "  \t<nav>\n",
      "\t\t<div id=\"wrap_nav\">\n",
      "\t\t\t<ul class=\"top_brand\">\n",
      "\t\t\t\t<li><a href=\"https://www.hanbit.co.kr/index.html\" name=\"hanbit_network\"><span>HOME</span></a></li>\n",
      "\t\t\t\t<li><a href=\"https://www.hanbit.co.kr/media/\">한빛미디어</a></li>\n",
      "\t\t\t\t<li><a href=\"https://www.hanbit.co.kr/academy/\">한빛아카데미</a></li>\n",
      "\t\t\t\t<li><a href=\"https://www.hanbit.co.kr/biz/\">한빛비즈</a></li>\n",
      "\t\t\t\t<li><a href=\"https://www.hanbit.co.kr/life/\">한빛라이프</a></li>\n",
      "\t\t\t\t<li><a href=\"https://www.hanbit.co.kr/edu/\">한빛에듀</a></li>\n",
      "\t\t\t\t<li><a href=\"https://www.hanbit.co.kr/realtime/\">리얼타임</a></li>\n",
      "\t\t\t\t<li><a href=\"https://www.hanbit.co.kr/textbook/\" target=\"_blank\">한빛정보교과서</a></li>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/rent/\" target=\"_blank\">한빛대관서비스</a></li>\n",
      "\t\t\t</ul>\n",
      "\t\t\t\n",
      "\t\t\t<ul class=\"top_menu\">\n",
      "                        \t<li><a href=\"https://www.hanbit.co.kr/member/login.html\" class=\"login\">로그인</a></li>\n",
      "\t\t\t\t<li><a href=\"https://www.hanbit.co.kr/member/member_agree.html\" class=\"join\">회원가입</a></li>\n",
      "\t\t\t\t<li><a href=\"https://www.hanbit.co.kr/myhanbit/myhanbit.html\" class=\"myhanbit\">마이한빛</a></li>\n",
      "\t\t\t\t<li><a href=\"https://www.hanbit.co.kr/myhanbit/cart.html\" class=\"cart\">장바구니</a></li>\n",
      "            \t\t\t\t<!-- <li class=\"top_menu_store\"><a href=\"https://www.hanbit.co.kr/store/store_submain.html\">STORE</a></li> -->\n",
      "\t\t\t</ul>\n",
      "\t\t</div>\n",
      "\t</nav>  <!-- //top menu -->\n",
      "\n",
      "  <div id=\"wrap_gnb\">\n",
      "    <!-- logo -->\n",
      "    <h1><a href=\"https://www.hanbit.co.kr/index.html\">한빛출판네트워크</a></h1>\n",
      "    <!-- //logo -->\n",
      "\n",
      "    <!-- Menu -->\n",
      "    <div id=\"gnb\" name=\"gnb\">\n",
      "      <ul>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/brand/brand_submain.html\" class=\"\">BRAND</a></li>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/channel/channel_submain.html\" class=\"\">Channel.H</a></li>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/store/store_submain.html\" class=\"curr\">STORE</a></li>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/support/help_info.html\" class=\"\">SUPPORT</a></li>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/event/current/current_event_list.html\" class=\"\">EVENT</a></li>\n",
      "        \n",
      "        <li id=\"top_search\" class=\"search\"><a href=\"javascript:;\" onClick=\"view_hover('main_search_area','','show'); $('#keyword_str').focus();\"><span>SERACH</span></a></li>\n",
      "      </ul>\n",
      "    </div>\n",
      "    <!-- //Menu -->\n",
      "    \n",
      "    <!-- lnb -->\n",
      "    <div class=\"lnb\" style=\"top:92px;\">\n",
      "      <div class=\"lnb_area\">\n",
      "      <!-- BRAND -->\n",
      "            <ul class=\"lnb_depth1_category\">\n",
      "        <li onmouseover=\"view_hover('category_store','','show')\" onMouseOut=\"view_hover('category_store','','hide')\"><a href=\"#\" onFocus=\"view_hover('category_store','','show')\" class=\"gnb_category\">카테고리</a>\n",
      "          <ul id=\"category_store\">\n",
      "\n",
      "                          <li onmouseover=\"view_hover('category_store1','','show')\" onMouseOut=\"view_hover('category_store1','','hide')\"><a href=\"/store/books/category_list.html?cate_cd=001\" onFocus=\"view_hover('category_store1','','show')\">IT/모바일</a>\n",
      "                <ul id=\"category_store1\">\n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=001001\">프로그래밍</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=001002\">웹</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=001003\">모바일/스마트기기</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=001013\">데이터베이스</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=001005\">운영체제</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=001014\">하드웨어</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=001015\">시스템/네트워크</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=001016\">보안</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=001009\">비즈니스/문화</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=001010\">게임</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=001017\">IT에세이</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=001012\">자격증</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=001018\">인공지능/데이터과학</a></li>      \n",
      "              </ul></li>              <li onmouseover=\"view_hover('category_store2','','show')\" onMouseOut=\"view_hover('category_store2','','hide')\"><a href=\"/store/books/category_list.html?cate_cd=002\" onFocus=\"view_hover('category_store2','','show')\">MAKE</a>\n",
      "                <ul id=\"category_store2\">\n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=002001\">Make 매거진</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=002002\">Make 프로젝트 북</a></li>      \n",
      "              </ul></li>              <li onmouseover=\"view_hover('category_store3','','show')\" onMouseOut=\"view_hover('category_store3','','hide')\"><a href=\"/store/books/category_list.html?cate_cd=003\" onFocus=\"view_hover('category_store3','','show')\">IT활용</a>\n",
      "                <ul id=\"category_store3\">\n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=003001\">오피스/OA</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=003002\">그래픽/멀티미디어</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=003003\">사진/예술</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=003004\">컴퓨터입문/IT교양</a></li>      \n",
      "              </ul></li>              <li onmouseover=\"view_hover('category_store4','','show')\" onMouseOut=\"view_hover('category_store4','','hide')\"><a href=\"/store/books/category_list.html?cate_cd=004\" onFocus=\"view_hover('category_store4','','show')\">대학교재</a>\n",
      "                <ul id=\"category_store4\">\n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=004007\">컴퓨터공학</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=004008\">정보통신/전기/전자</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=004003\">수학/과학/공학</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=004004\">프로그래밍/웹</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=004005\">그래픽/디자인</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=004006\">OA/활용</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=004009\">수험서/자격증</a></li>      \n",
      "              </ul></li>              <li onmouseover=\"view_hover('category_store5','','show')\" onMouseOut=\"view_hover('category_store5','','hide')\"><a href=\"/store/books/category_list.html?cate_cd=006\" onFocus=\"view_hover('category_store5','','show')\">실용서</a>\n",
      "                <ul id=\"category_store5\">\n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=006001\">취미/실용</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=006002\">여행</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=006003\">건강</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=006004\">유아/육아</a></li>      \n",
      "              </ul></li>              <li onmouseover=\"view_hover('category_store6','','show')\" onMouseOut=\"view_hover('category_store6','','hide')\"><a href=\"/store/books/category_list.html?cate_cd=007\" onFocus=\"view_hover('category_store6','','show')\">경제/경영/인문</a>\n",
      "                <ul id=\"category_store6\">\n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=007001\">경제/경영</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=007002\">자기계발</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=007003\">인문/교양</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=007004\">마케팅</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=007005\">에세이</a></li>      \n",
      "              </ul></li>              <li onmouseover=\"view_hover('category_store7','','show')\" onMouseOut=\"view_hover('category_store7','','hide')\"><a href=\"/store/books/category_list.html?cate_cd=008\" onFocus=\"view_hover('category_store7','','show')\">유아/어린이/초등</a>\n",
      "                <ul id=\"category_store7\">\n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=008001\">4~6세</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=008002\">5~7세</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=008003\">예비초등</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=008004\">초등교과연계 1~12영역</a></li>      \n",
      "                              <li><a href=\"/store/books/category_list.html?cate_cd=008005\">초등 전학년</a></li>      \n",
      "              </ul></li>            \n",
      "          <!-- 항상 노출 메뉴 -->          \n",
      "          <li class=\"gnb_category_series\"><a href=\"https://www.hanbit.co.kr/store/books/series_list.html\">시리즈</a></li>\n",
      "          <li class=\"gnb_category_reservations\"><a href=\"https://www.hanbit.co.kr/store/books/reservations_list.html\">예약도서</a></li>\n",
      "          <!--\n",
      "          <li class=\"gnb_category_full\"><a href=\"https://www.hanbit.co.kr/store/books/full_book_list.html\">전체도서목록</a></li>\n",
      "          -->\n",
      "          <!--/li-->\n",
      "        </ul>\n",
      "      </ul>\n",
      "      <!--/li-->        \n",
      "      <!--/ul-->\n",
      "\n",
      "      <ul class=\"lnb_depth1\">\n",
      "        <li><a href=\"https://www.hanbit.co.kr/store/books/new_book_list.html\">새로나온 책</a></li><span>l</span>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/store/books/bestseller_list.html\">베스트셀러</a></li><span>l</span>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/store/books/full_book_list.html\">전체도서목록</a></li><span>l</span>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/store/education/edu_list.html\">교육</a></li><span>l</span>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/store/item/item_list.html\">Item &amp; Maker Shed</a></li>\n",
      "      </ul>\n",
      "      \n",
      "      <!-- SUPPORT -->\n",
      "          </div>\n",
      "    </div>\n",
      "    <!--// lnb -->\n",
      "  </div>\n",
      "</header>\n",
      "<!-- //header -->\n",
      "\n",
      "<!-- 메인 검색 및 카테고리 영역 -->\n",
      "<div id=\"main_search_area\" class=\"fixed\" style=\"display:none;\">\n",
      "  <div class=\"msa_wrap\">\n",
      "\n",
      "    <!-- 검색 -->\n",
      "    <div class=\"msa_srch_wrap\">\n",
      "      <form onsubmit=\"return false;\">\n",
      "      <fieldset class=\"msa_srch_field\">\n",
      "        <legend>한빛출판네트워크 검색</legend>\n",
      "        <input title=\"검색어\" autocomplete=\"off\" class=\"srch_keyword\" accesskey=\"s\" type=\"text\" name=\"keyword_str\" id=\"keyword_str\" v-model=\"keyword\" @input=\"typeKeyword\">\n",
      "        <input type=\"submit\" class=\"srch_btn\" style=\"cursor:pointer;\" @click=\"clickSearch\">\n",
      "      </fieldset>\n",
      "      </form>\n",
      "    </div>\n",
      "    <!-- //검색 -->\n",
      "\n",
      "    <!-- ① 인기검색어 -->\n",
      "    <div class=\"msa_srch_polular\" v-if=\"showPopularKeyword === true\">\n",
      "      <h2 class=\"tit\">인기 검색어 <span>(최근 1개월간)</span></h2>\n",
      "        <div class=\"popula_box\">\n",
      "          <ul class=\"left\">\n",
      "            <li v-for=\"keyword in leftPopularKeywordList\">\n",
      "              <a :class=\"keyword.bold\" @click=\"clickPopularKeyword(keyword)\">\n",
      "                  {{ keyword.number }} {{ keyword.bookName }}\n",
      "              </a>\n",
      "            </li>\n",
      "          </ul>\n",
      "          <ul class=\"right\">\n",
      "            <li v-for=\"keyword in rightPopularKeywordList\">\n",
      "              <a :class=\"keyword.bold\" @click=\"clickPopularKeyword(keyword)\">\n",
      "                  {{ keyword.number }} {{ keyword.bookName }}\n",
      "              </a>\n",
      "            </li>\n",
      "          </ul>\n",
      "        </div>\n",
      "    </div>\n",
      "    <!-- ① 인기검색어 -->\n",
      "\n",
      "    <!-- ② 검색결과/검색서제스쳔 -->\n",
      "    <div class=\"msa_srch_suggestion\" v-if=\"showPopularKeyword === false\">\n",
      "      <div class=\"sugg_left\" v-if=\"bookList.length !== 0\">\n",
      "        <h3 class=\"tit\">BOOK</h3>\n",
      "        <ul class=\"books_list\">\n",
      "          <li v-for=\"book in bookList\" @mouseover=\"mouseOverBook(book.id)\"><a @click=\"clickBookKeyword(book)\"><p v-html=\"book.name\"></p></a></li>\n",
      "        </ul>\n",
      "      </div>\n",
      "\n",
      "      <div class=\"sugg_right\">\n",
      "        <div class=\"sugg_book\" v-if=\"bookList.length !== 0\">\n",
      "          <table class=\"sugg_book_detail\">\n",
      "            <tr>\n",
      "              <td class=\"cover\">\n",
      "                <a @click=\"clickBookKeyword(bookSummary)\">\n",
      "                  <img :src=\"bookSummary.imgUrl\" class=\"b_cover\">\n",
      "                </a>\n",
      "              </td>\n",
      "              <td class=\"draft\">\n",
      "                <a @click=\"clickBookKeyword(bookSummary)\" class=\"b_title\"><strong v-html=\"bookSummary.originName\"></strong></a>\n",
      "                <p class=\"b_int\">\n",
      "                {{ bookSummary.author }} 지음<br />\n",
      "                {{ bookSummary.publishingCompany }} | {{ bookSummary.date }}\n",
      "                </p>\n",
      "                <p class=\"b_type\">\n",
      "                <span>{{ bookSummary.bookType }}</span>\n",
      "                </p>\n",
      "              </td>\n",
      "            </tr>\n",
      "          </table>\n",
      "        </div>\n",
      "\n",
      "        <div class=\"sugg_edu\" v-if=\"educationList.length !== 0\">\n",
      "          <h3 class=\"tit\">EDUCATION</h3>\n",
      "          <ul class=\"edu_list\">\n",
      "            <li v-for=\"education in educationList\">&#149; <a @click=\"clickEducationKeyword(education)\"><span v-html=\"education.title\"></span></a></li>\n",
      "          </ul>\n",
      "        </div>\n",
      "\n",
      "        <div class=\"sugg_cont\" v-if=\"contentList.length !== 0\">\n",
      "          <h3 class=\"tit\">CONTENTS</h3>\n",
      "          <ul class=\"cont_list\">\n",
      "            <li v-for=\"content in contentList\">&#149; <a @click=\"clickContentKeyword(content)\"><span v-html=\"content.title\"></span></a></li>\n",
      "          </ul>\n",
      "        </div>\n",
      "      </div>\n",
      "    </div>\n",
      "    <!-- //② 검색결과/검색서제스쳔 -->\n",
      "\n",
      "  <!-- 닫기 -->\n",
      "  <div class=\"msa_wrap_close\">\n",
      "    <a href=\"javascript:;\" onclick=\"view_hover('main_search_area','','hide')\">닫기</a>\n",
      "  </div>\n",
      "  <!-- //닫기 -->\n",
      "\n",
      "  </div>\n",
      "</div>\n",
      "\n",
      "<!-- old // 구현시 필요없으면 삭제해도 됩니다.\n",
      "<script type=\"text/javascript\">\n",
      "  function sch_smit(){\n",
      "    if(!$.trim($(\"#keyword_str\").val()).length) {\n",
      "      alert(\"검색어를 입력해주세요\");\n",
      "      $(\"#keyword_str\").focus();\n",
      "      return false;\n",
      "    }else{\n",
      "      $(\"#gnbsearchfrm\").attr(\"action\",\"/search/search_list.html\");\n",
      "      $(\"#gnbsearchfrm\").submit(); \n",
      "    }\n",
      "  }\n",
      "</script>\n",
      "-->\n",
      "\n",
      "<script type=\"text/javascript\">\n",
      "    \"use strict\";\n",
      "\n",
      "    var common_top_search_vue = new Vue({\n",
      "        el: '#main_search_area',\n",
      "        data: {\n",
      "            //검색엔진 URL\n",
      "            searchProxyURL: \"https://search.hanbit.co.kr\",\n",
      "            //인기 검색어 show 여부\n",
      "            showPopularKeyword: true,\n",
      "            //사용자 검색 키워드\n",
      "            keyword: '',\n",
      "            //인기 검색어 리스트\n",
      "            popularKeywordList: [],\n",
      "            // 인기 검색어 리스트 (왼쪽)\n",
      "            leftPopularKeywordList: [],\n",
      "            // 인기 검색어 리스트 (오른쪽)\n",
      "            rightPopularKeywordList: [],\n",
      "            // 자동완성에서의 책 리스트\n",
      "            bookList: [],\n",
      "            // 자동완성에서의 책 정보\n",
      "            bookSummary: {\n",
      "                'imgUrl': '',\n",
      "                'link': '',\n",
      "                'name': '',\n",
      "                'author': '',\n",
      "                'publishingCompany': '',\n",
      "                'date': '',\n",
      "                'bookType': ''\n",
      "            },\n",
      "            //에듀케이션 리스트\n",
      "            educationList: [],\n",
      "            //컨텐츠 리스트\n",
      "            contentList: []\n",
      "        },\n",
      "        created: function created() {\n",
      "            // 인기 검색어 조회\n",
      "            this.getPopularKeyword();\n",
      "        },\n",
      "        methods: {\n",
      "            /**\n",
      "             * 사용자가 검색 키워드를 입력할때 발생하는 이벤트\n",
      "             */\n",
      "            typeKeyword: function typeKeyword() {\n",
      "                var self = this;\n",
      "                var keyword = $(\"#keyword_str\").val();\n",
      "\n",
      "                if (keyword.length !== 0) {\n",
      "                    //자동완성어\n",
      "                    this.findAutocompleteResult(keyword);\n",
      "                } else {\n",
      "                    //인기검색어\n",
      "                    self.showPopularKeyword = true;\n",
      "                }\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * 인기검색어 조회\n",
      "             */\n",
      "            getPopularKeyword: function getPopularKeyword() {\n",
      "                var self = this;\n",
      "                this.popularKeywordList = [];\n",
      "                $.get(this.searchProxyURL + \"/querylog/popularKeyword\").done(function (data) {\n",
      "                    if (data != null) {\n",
      "                        self.drawPopularKeyword(data);\n",
      "                    }\n",
      "                });\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * 인기 검색어 그리기\n",
      "             */\n",
      "            drawPopularKeyword: function drawPopularKeyword(popularBooks) {\n",
      "                var self = this;\n",
      "                popularBooks.forEach(function (item) {\n",
      "                    var popularBook = {\n",
      "                        bookName: item.keyword\n",
      "                    };\n",
      "                    self.popularKeywordList.push(popularBook);\n",
      "                });\n",
      "                var number = 0;\n",
      "\n",
      "                for (var _iterator = this.popularKeywordList, _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {\n",
      "                    var _ref;\n",
      "\n",
      "                    if (_isArray) {\n",
      "                        if (_i >= _iterator.length) break;\n",
      "                        _ref = _iterator[_i++];\n",
      "                    } else {\n",
      "                        _i = _iterator.next();\n",
      "                        if (_i.done) break;\n",
      "                        _ref = _i.value;\n",
      "                    }\n",
      "\n",
      "                    var keyword = _ref;\n",
      "                    number = number + 1;\n",
      "                    keyword.number = number.toString().length < 2 ? \"0\" + number : number;\n",
      "\n",
      "                    if (number > 5) {\n",
      "                        keyword.direction = \"right\";\n",
      "                        self.rightPopularKeywordList.push(keyword);\n",
      "                    } else {\n",
      "                        keyword.direction = \"left\";\n",
      "\n",
      "                        if (number < 4) {\n",
      "                            keyword.bold = 'active';\n",
      "                        }\n",
      "\n",
      "                        self.leftPopularKeywordList.push(keyword);\n",
      "                    }\n",
      "                }\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * 자동완성 검색 결과\n",
      "             */\n",
      "            findAutocompleteResult: function findAutocompleteResult(keyword) {\n",
      "                var self = this;\n",
      "                var param = {\n",
      "                    q: keyword,\n",
      "                    types: \"education,book,contents\",\n",
      "                    fq: keyword\n",
      "                };\n",
      "                $.post(this.searchProxyURL + \"/autocomplete/search\", param).done(function (data) {\n",
      "                    if (data != null) {\n",
      "                        var bookResult = data.booksResults;\n",
      "                        self.changeBookList(keyword, bookResult);\n",
      "                        var contentResult = data.contentsResults;\n",
      "                        self.changeContentList(keyword, contentResult);\n",
      "                        var educationResult = data.educationResults;\n",
      "                        self.changeEducationList(keyword, educationResult);\n",
      "                    }\n",
      "                });\n",
      "                this.showPopularKeyword = false;\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * 자동완성어에서 BOOK 부분에서 마우스를 올렸을 시에 발생하는 이벤트\n",
      "             * @param bookId\n",
      "             */\n",
      "            mouseOverBook: function mouseOverBook(bookId) {\n",
      "                var currentBook = this.bookList.filter(function (book) {\n",
      "                    return book.id === bookId;\n",
      "                });\n",
      "                this.changeBookSummary(currentBook[0]);\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * 책 소개 변경\n",
      "             * @param book\n",
      "             */\n",
      "            changeBookSummary: function changeBookSummary(book) {\n",
      "                if (book !== {}) {\n",
      "                    this.bookSummary.name = book.name;\n",
      "                    this.bookSummary.originName = book.originName;\n",
      "                    this.bookSummary.author = book.author;\n",
      "                    this.bookSummary.bookType = book.bookType;\n",
      "                    this.bookSummary.imgUrl = book.imgUrl;\n",
      "                    this.bookSummary.link = book.link;\n",
      "                    this.bookSummary.publishingCompany = book.publishingCompany;\n",
      "                    this.bookSummary.date = book.date;\n",
      "                    this.bookSummary.bookType = book.bookType;\n",
      "                }\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * BOOK 리스트 변경\n",
      "             */\n",
      "            changeBookList: function changeBookList(keyword, bookResultList) {\n",
      "                var self = this;\n",
      "                self.bookList = [];\n",
      "                var index = 0;\n",
      "\n",
      "                if (bookResultList != null) {\n",
      "                    for (var _iterator2 = bookResultList, _isArray2 = Array.isArray(_iterator2), _i2 = 0, _iterator2 = _isArray2 ? _iterator2 : _iterator2[Symbol.iterator]();;) {\n",
      "                        var _ref2;\n",
      "\n",
      "                        if (_isArray2) {\n",
      "                            if (_i2 >= _iterator2.length) break;\n",
      "                            _ref2 = _iterator2[_i2++];\n",
      "                        } else {\n",
      "                            _i2 = _iterator2.next();\n",
      "                            if (_i2.done) break;\n",
      "                            _ref2 = _i2.value;\n",
      "                        }\n",
      "\n",
      "                        var result = _ref2;\n",
      "\n",
      "                        if (index < 10) {\n",
      "                            var book = {};\n",
      "                            book.id = result.code;\n",
      "                            book.originName = result.title;\n",
      "                            book.name = JSON.parse(JSON.stringify(self.replaceHighlightWord(result.title, keyword)));\n",
      "                            book.link = result.code;\n",
      "                            book.imgUrl = self.getBookImageURL(result.code);\n",
      "                            book.author = result.author;\n",
      "                            book.publishingCompany = result.brand;\n",
      "                            book.date = result.pubDate;\n",
      "                            book.bookType = result.bookType;\n",
      "                            self.bookList.push(book); //책 미리보기 변경\n",
      "\n",
      "                            self.changeBookSummary(self.bookList[0]);\n",
      "                        }\n",
      "                    }\n",
      "                } else {\n",
      "                    self.initBookSummary();\n",
      "                }\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * 책 이미지 주소 가져오기\n",
      "             */\n",
      "            getBookImageURL: function getBookImageURL(bookCode) {\n",
      "                var imgURL;\n",
      "\n",
      "                if (bookCode.substr(0, 1) === \"E\") {\n",
      "                    imgURL = '/data/ebook/' + bookCode + '_m.jpg';\n",
      "                } else {\n",
      "                    imgURL = '/data/books/' + bookCode + \"_m.jpg\";\n",
      "                }\n",
      "\n",
      "                return imgURL;\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * 검색 결과가 없을 경우 책 미리보기 초기화\n",
      "             */\n",
      "            initBookSummary: function initBookSummary() {\n",
      "                this.bookSummary = {\n",
      "                    'imgUrl': '',\n",
      "                    'link': '',\n",
      "                    'name': '',\n",
      "                    'author': '',\n",
      "                    'publishingCompany': '',\n",
      "                    'date': '',\n",
      "                    'bookType': ''\n",
      "                };\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * education 리스트 변경\n",
      "             */\n",
      "            changeEducationList: function changeEducationList(keyword, educationResultList) {\n",
      "                var self = this;\n",
      "                self.educationList = [];\n",
      "                var index = 0;\n",
      "\n",
      "                if (educationResultList != null) {\n",
      "                    for (var _iterator3 = educationResultList, _isArray3 = Array.isArray(_iterator3), _i3 = 0, _iterator3 = _isArray3 ? _iterator3 : _iterator3[Symbol.iterator]();;) {\n",
      "                        var _ref3;\n",
      "\n",
      "                        if (_isArray3) {\n",
      "                            if (_i3 >= _iterator3.length) break;\n",
      "                            _ref3 = _iterator3[_i3++];\n",
      "                        } else {\n",
      "                            _i3 = _iterator3.next();\n",
      "                            if (_i3.done) break;\n",
      "                            _ref3 = _i3.value;\n",
      "                        }\n",
      "\n",
      "                        var result = _ref3;\n",
      "\n",
      "                        if (index < 3) {\n",
      "                            var content = {};\n",
      "                            content.title = JSON.parse(JSON.stringify(self.replaceHighlightWord(result.title, keyword)));\n",
      "                            content.link = result.code;\n",
      "                            self.educationList.push(content);\n",
      "                            index = index + 1;\n",
      "                        }\n",
      "                    }\n",
      "                }\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * contents 리스트 변경\n",
      "             */\n",
      "            changeContentList: function changeContentList(keyword, contentResult) {\n",
      "                var self = this;\n",
      "                self.contentList = [];\n",
      "                var index = 0;\n",
      "\n",
      "                if (contentResult != null) {\n",
      "                    for (var _iterator4 = contentResult, _isArray4 = Array.isArray(_iterator4), _i4 = 0, _iterator4 = _isArray4 ? _iterator4 : _iterator4[Symbol.iterator]();;) {\n",
      "                        var _ref4;\n",
      "\n",
      "                        if (_isArray4) {\n",
      "                            if (_i4 >= _iterator4.length) break;\n",
      "                            _ref4 = _iterator4[_i4++];\n",
      "                        } else {\n",
      "                            _i4 = _iterator4.next();\n",
      "                            if (_i4.done) break;\n",
      "                            _ref4 = _i4.value;\n",
      "                        }\n",
      "\n",
      "                        var result = _ref4;\n",
      "\n",
      "                        if (index < 3) {\n",
      "                            var content = {};\n",
      "                            content.title = JSON.parse(JSON.stringify(self.replaceHighlightWord(result.title, keyword)));\n",
      "                            content.link = result.code;\n",
      "                            self.contentList.push(content);\n",
      "                            index = index + 1;\n",
      "                        }\n",
      "                    }\n",
      "                }\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * 하이라이트 표시\n",
      "             */\n",
      "            replaceHighlightWord: function replaceHighlightWord(str, highlightKeyword) {\n",
      "                var replaceHighlightKeyword = highlightKeyword.replace(/[^a-z0-9가-힣_ ]/gi, '');\n",
      "                var regEx = new RegExp(replaceHighlightKeyword, \"gi\");\n",
      "                str = str.replace(regEx, function (a) {\n",
      "                    return '<span class=\"keysel\">' + a + '</span>';\n",
      "                });\n",
      "                return str;\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * 검색 버튼 클릭 시\n",
      "             * @param e\n",
      "             */\n",
      "            clickSearch: function clickSearch(e) {\n",
      "                if (!this.keyword || this.keyword.length === 0) {\n",
      "                    alert(\"검색어를 입력하세요\");\n",
      "                    $(\"#keyword_str\").focus();\n",
      "                    e.preventDefault();\n",
      "                } else {\n",
      "                    location.href = \"/search/search_list.html?keyword=\" + this.keyword;\n",
      "                }\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * 인기 검색어 클릭시\n",
      "             * @param book\n",
      "             */\n",
      "            clickPopularKeyword: function clickPopularKeyword(book) {\n",
      "                var searchKeyword = book.bookName;\n",
      "                location.href = \"/search/search_list.html?keyword=\" + searchKeyword;\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * 책 검색어 클릭시 책 상세로 이동\n",
      "             * @param book\n",
      "             */\n",
      "            clickBookKeyword: function clickBookKeyword(book) {\n",
      "                location.href = \"/store/books/look.php?p_code=\" + book.link;\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * 교육 클릭시 교육 상세로 이동\n",
      "             * @param education\n",
      "             */\n",
      "            clickEducationKeyword: function clickEducationKeyword(education) {\n",
      "                location.href = \"/store/education/edu_view.html?p_code=\" + education.link;\n",
      "            },\n",
      "\n",
      "            /**\n",
      "             * 컨텐츠 클릭시 컨텐츠 상세로 이동\n",
      "             * @param contents\n",
      "             */\n",
      "            clickContentKeyword: function clickContentKeyword(content) {\n",
      "                location.href = \"/channel/category/category_view.html?cms_code=\" + content.link;\n",
      "            }\n",
      "        }\n",
      "    });\n",
      "</script>\n",
      "<!-- //메인 검색 및 카테고리 영역 -->\n",
      "\n",
      "<!-- Contents -->\n",
      "<div id=\"container\">\n",
      "\t<div class=\"docu_title\">\n",
      "\t\t<h2>전체도서목록</h2>\n",
      "\t</div>\n",
      "\t\n",
      "\t<!-- 전체도서목록 wrap -->\n",
      "\t<div class=\"full_book_list_wrap\">\n",
      "\t\t<!-- 브랜드 정렬 버튼 -->\n",
      "\t\t\n",
      "        <div class=\"btn_brand_area\">       \n",
      "\t\t\t<ul>\n",
      "\t\t\t\t<li class=\"curr\">\n",
      "                \t<a href=\"/store/books/full_book_list.html\">\n",
      "                    \t                    <span class=\"name_full\">전체</span>\n",
      "                                        </a>\n",
      "                    \n",
      "                </li>\n",
      "\t\t\t\t<li >\n",
      "\t\t\t\t\t<a href=\"/store/books/full_book_list.html?brand=HM\">\n",
      "                                        \t<span class=\"name_abbr\">M</span>\n",
      "                    \t\t\t\t\t</a>\n",
      "\t\t\t\t</li>\n",
      "\n",
      "\t\t\t\t<li >\n",
      "                \t<a href=\"/store/books/full_book_list.html?brand=HA\">\n",
      "                                        \t<span class=\"name_abbr\">A</span>\n",
      "                    \t\t\t\t\t</a>\n",
      "                </li>\n",
      "\t\t\t\t<li >\n",
      "                \t<a href=\"/store/books/full_book_list.html?brand=HB\">\n",
      "                                        \t<span class=\"name_abbr\">B</span>\n",
      "                    \t\t\t\t\t</a>\n",
      "                </li>\n",
      "\t\t\t\t<li >\n",
      "                \t<a href=\"/store/books/full_book_list.html?brand=HL\">\n",
      "                                        \t<span class=\"name_abbr\">L</span>\n",
      "                    \t\t\t\t\t</a>\n",
      "                </li>\n",
      "\t\t\t\t<li >\n",
      "                \t<a href=\"/store/books/full_book_list.html?brand=HE\">\n",
      "                                        \t<span class=\"name_abbr\">E</span>\n",
      "                    \t\t\t\t\t</a>\n",
      "                </li>\n",
      "\t\t\t\t<li >\n",
      "                \t<a href=\"/store/books/full_book_list.html?brand=HR\">\n",
      "                                        \t<span class=\"name_abbr\">R</span>\n",
      "                    \t\t\t\t\t</a>\n",
      "                </li>\n",
      "\t\t\t\t<li >\n",
      "                \t<a href=\"/store/books/full_book_list.html?brand=MK\">\n",
      "                                        \t<span class=\"name_abbr\">MK</span>\n",
      "                    \t\t\t\t\t</a>\n",
      "                </li>\n",
      "\t\t\t\t\n",
      "\t\t\t</ul>\n",
      "\t\t</div>\n",
      "\n",
      "\n",
      "\n",
      "\t\t<!-- //브랜드 정렬 버튼 -->\n",
      "\t\t\n",
      "\t\t<!-- 출간일/도서명 순-->\n",
      "\t\t<div class=\"series_lineup\">\n",
      "\t\t\t<ul>\n",
      "\t\t\t\t<li><a href=\"/store/books/full_book_list.html?srt=p_pub_date&brand=\"  class=\"curr\" >출간일 순</a></li>\n",
      "\t\t\t\t<li><a href=\"/store/books/full_book_list.html?srt=p_title&brand=\" >도서명 순</a></li>\n",
      "\t\t\t</ul>\n",
      "\t\t</div>\n",
      "\t\t<!-- //출간일/도서명 순-->\n",
      "\t\t\n",
      "\t\t<!-- 전체 목록 다운로드 버튼-->\n",
      "\t\t<div class=\"btn_full_list\"><a href=\"javascript:document.frm.submit();\">전체 목록 다운로드</a></div>\n",
      "\t\t\n",
      "\t\t<!-- 책 리스트 -->\n",
      "\t\t<div class=\"table_area\">\n",
      "\t\t\t<table class=\"tbl_type_list\" border=\"0\" cellspacing=\"0\" summary=\"전체목록 리스트 테이블\">\n",
      "\t\t\t\t<caption>전체목록 리스트</caption>\n",
      "\t\t\t\t<colgroup>\n",
      "\t\t\t\t<col width=\"180px\">\n",
      "\t\t\t\t<col width=\"\">\n",
      "\t\t\t\t<col width=\"160px\">\n",
      "\t\t\t\t<col width=\"134px\">\n",
      "\t\t\t\t<col width=\"130px\">\n",
      "\t\t\t\t</colgroup>\n",
      "\t\t\t\t<thead>\n",
      "\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<th scope=\"col\">브랜드</th>\n",
      "\t\t\t\t\t\t<th scope=\"col\">도서명</th>\n",
      "\t\t\t\t\t\t<th scope=\"col\">저자</th>\n",
      "\t\t\t\t\t\t<th scope=\"col\">발행일</th>\n",
      "\t\t\t\t\t\t<th scope=\"col\">정가</th>\n",
      "\t\t\t\t\t</tr>\n",
      "\t\t\t\t</thead>\n",
      "\t\t\t\t<tbody>\n",
      "\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B7026921929\">파이썬 증권 데이터 분석</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">김황후   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-07-01</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">32,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B3745711486\">나의 첫 파이썬&#40;2판&#41;</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">에릭 마테스   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-07-01</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">30,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_l\">한빛라이프</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B7748014142\">나는 왜 네 말이 힘들까</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">박재연   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-07-01</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">16,800원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B9609283195\">혼자 공부하는 첫 프로그래밍 with 파이썬</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">문현일   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-30</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">17,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_b\">한빛비즈</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B7346049104\">퇴근길 인문학 수업 : 뉴노멀</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">백상경제연구원 외 12명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-30</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">17,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_a\">한빛아카데미</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B4295361584\">IT CookBook, 초연결 사회의 데이터통신과 네트워킹</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">강문식   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-30</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">29,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B7859887743\">실전 자바 소프트웨어 개발</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">라울-게이브리얼 우르마 외 1명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-20</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">18,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_a\">한빛아카데미</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B3126325886\">IT CookBook, 쉽게 배우는 MFC 윈도우 프로그래밍</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">김선우 외 1명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-20</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">30,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_a\">한빛아카데미</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B3715221949\">IT CookBook, 인공지능 시대를 위한 컴퓨터 과학 개론</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">정기철   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-19</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">27,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_b\">한빛비즈</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B3354514449\">까면서 보는 해부학 만화</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">압듈라 외 1명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-19</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">18,500원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_a\">한빛아카데미</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B3055805288\">IT CookBook, 코틀린을 활용한 안드로이드 프로그래밍</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">우재남 외 1명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-19</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">34,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_b\">한빛비즈</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B1789503265\">뱅크 4.0</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">브렛 킹   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-15</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">18,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B1047711884\">클라우드 네이티브</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">보리스 숄 외 2명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-13</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">22,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_a\">한빛아카데미</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B4872546419\">IT CookBook, 처음 만나는 신재생에너지</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">김지홍   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-10</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">25,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_a\">한빛아카데미</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B1710834745\">프리드버그 선형대수학</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">스티븐 H. 프리드버그 외 2명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-05</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">35,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B9632716381\">이더리움 디앱 개발</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">로베르토 인판테   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-04</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">40,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B7283790591\">딥러닝과 바둑</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">막스 펌펄라 외 1명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-01</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">36,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_b\">한빛비즈</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B8151169674\">CIA 요원, 최강 비즈니스맨이 되다</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">제이슨 핸슨   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-01</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">15,800원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B3669653041\">필수 공식으로 하루에 하나씩 정복하는 엑셀 업무 공략집</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">최준선   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-06-01</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">19,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_a\">한빛아카데미</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B8200129293\">IT CookBook, CentOS 리눅스</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">이종원   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-30</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">32,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_b\">한빛비즈</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B8912615747\">2020 부동산 세금 사용설명서</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">김성일   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-26</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">11,200원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_b\">한빛비즈</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B6465057927\">내러티브 앤 넘버스</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">애스워드 다모다란   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-20</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">18,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_e\">한빛에듀</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B1158791094\">똑똑한 두뇌 연습 : 세계 여행 다른 그림 찾기</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">제니 에스피노사   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-15</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">8,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_e\">한빛에듀</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B3778443233\">똑똑한 두뇌 연습 : 점 잇기</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">조 문   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-15</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">8,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_b\">한빛비즈</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B2894027772\">포스트 코로나</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">임승규(국제경제) 외 6명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-15</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">18,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_e\">한빛에듀</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B8852889897\">똑똑한 두뇌 연습 100 : 공주, 동물, 색칠 세트</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">발롱 미디어   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-15</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">18,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_e\">한빛에듀</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B3895086770\">똑똑한 두뇌 연습 100 : 탈것, 동물, 축구 세트</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">발롱 미디어   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-15</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">18,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B4731993755\">만들면서 배우는 워드프레스 &#40;개정2판&#41;</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">박현우   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-11</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">26,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B2064300579\">이것이 MySQL이다&#40;개정판&#41;</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">우재남   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-10</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">32,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_e\">한빛에듀</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B2926273381\">미로 마스터 LEVEL2. 미스터리 미로</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">마크 워커   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-08</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">8,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_e\">한빛에듀</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B8703048424\">미로 마스터 LEVEL3. 크레이지 미로</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">사이먼 워드   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-08</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">8,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B6867862379\">회사에서 바로 통하는 파워포인트 FOR STARTERS</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">이화진   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-07</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">15,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B7033438574\">핸즈온 머신러닝&#40;2판&#41;</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">오렐리앙 제롱(Aurélien Géron)   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-04</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">55,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B6796857324\">배워서 바로 쓰는 스프링 프레임워크</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">애시시 사린 외 1명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-01</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">50,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B4068078736\">BPF로 리눅스 관측 가능성 향상하기</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">데이비드 칼라베라 외 1명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-05-01</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">22,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_b\">한빛비즈</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B9883631255\">4차 인간</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">이미솔 외 1명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-30</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">16,800원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_b\">한빛비즈</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B9839456081\">할짝 심리학</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">이한나   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-30</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">15,800원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B4070147419\">이것이 안드로이드다 with 코틀린</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">고돈호   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-25</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">34,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_b\">한빛비즈</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B8029392566\">나는 불평을 그만두기로 했다</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">크리스틴 르위키   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-20</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">15,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_l\">한빛라이프</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B8977162495\">오늘도 화내고 말았습니다</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">박윤미   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-20</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">14,800원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B5218628357\">배워서 바로 쓰는 스프링 부트 2</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">히로스에 다케시 외 1명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-16</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">28,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B9288599157\">학교에서 알려주지 않는 17가지 실무 개발 기술</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">이기곤   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-16</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">20,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B8529915277\">이것이 리눅스다 &#40;개정판&#41; with RedHat CentOS 8</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">우재남   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-10</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">32,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B6634694521\">회사에서 바로 통하는  실무 엑셀+파워포인트+워드&한글&#40;개정판&#41;</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">전미진 외 2명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-10</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">22,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_b\">한빛비즈</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B8958054405\">은밀한 설계자들</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">클라이브 톰슨   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-06</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">25,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_m\">한빛미디어</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B3156242562\">줄리아를 생각하다</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">벤 로언스 외 1명  </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-06</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">30,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_b\">한빛비즈</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B7546247400\">타겟티드</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">브리태니 카이저   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-06</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">18,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_a\">한빛아카데미</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B2049588591\">누구나 파이썬 통계분석</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">타니아이 히로키   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-06</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">26,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_b\">한빛비즈</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B7581841106\">이기적 유인원</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">니컬러스 머니   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-03</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">17,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\t<tr>\n",
      "\t\t\t\t\t\t<td class=\"brd_e\">한빛에듀</td>\n",
      "\t\t\t\t\t\t<td class=\"left\"><a href=\"/store/books/look.php?p_code=B1047898750\">미로 마스터 LEVEL1. 세계 미로 대탈출</a></td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t\t<td class=\"left\">앤디 피터스   </td>\n",
      "\t\t\t\t\t\t\t\t\t\t\t\t<td>2020-04-03</td>\n",
      "\t\t\t\t\t\t<td class=\"right\">8,000원</td>\n",
      "\t\t\t\t\t</tr>\n",
      "\n",
      "\t\t\t\t\t\t\t\t\t\n",
      "\t\t\t\t</tbody>\n",
      "\t\t\t</table>\n",
      "\t\t</div>\n",
      "\t\t<!-- //책 리스트 -->\n",
      "\t\t\n",
      "\t\t<!-- 페이징 -->\n",
      "\t\t<div class=\"paginate bdr_no\">\n",
      "\t\t\t<strong>1</strong>\n",
      "<a href=\"/store/books/full_book_list.html?page=2&srt=p_pub_date&brand=\">2</a>\n",
      "<a href=\"/store/books/full_book_list.html?page=3&srt=p_pub_date&brand=\">3</a>\n",
      "<a href=\"/store/books/full_book_list.html?page=4&srt=p_pub_date&brand=\">4</a>\n",
      "<a href=\"/store/books/full_book_list.html?page=5&srt=p_pub_date&brand=\">5</a>\n",
      "<a href=\"/store/books/full_book_list.html?page=6&srt=p_pub_date&brand=\">6</a>\n",
      "<a href=\"/store/books/full_book_list.html?page=7&srt=p_pub_date&brand=\">7</a>\n",
      "<a href=\"/store/books/full_book_list.html?page=8&srt=p_pub_date&brand=\">8</a>\n",
      "<a href=\"/store/books/full_book_list.html?page=9&srt=p_pub_date&brand=\">9</a>\n",
      "<a href=\"/store/books/full_book_list.html?page=10&srt=p_pub_date&brand=\">10</a>\n",
      "<a href=\"/store/books/full_book_list.html?page=11&srt=p_pub_date&brand=\" class=\"next\"><span>&gt;</span></a>\n",
      "\t\t</div>\n",
      "\t\t<!-- //페이징 -->\n",
      "\t\t\n",
      "\t\t<!-- 전체 목록 다운로드 버튼-->\n",
      "\t\t<div class=\"btn_full_list mt40\"><a href=\"javascript:document.frm.submit();\">전체 목록 다운로드</a></div>\n",
      "\t\n",
      "\t</div>\n",
      "\t<!-- //전체도서목록 wrap -->\t\n",
      "\t\n",
      "</div>\n",
      "<!-- //Contents -->\n",
      "<form name=\"frm\" id=\"frm\" method=\"post\" action=\"./full_book_list_down.php\">\n",
      "<input type=\"hidden\" name=\"brand\" id=\"brand\" value=\"\">\n",
      "<input type=\"hidden\" name=\"srt\" id=\"srt\" value=\"p_pub_date\">\n",
      "</form>\n",
      "<!-- Footer -->\n",
      "<footer>\n",
      "  <!-- 공지사항 -->\n",
      "  <div class=\"foot_notice\">\n",
      "        <span>\n",
      "      <a href=\"https://www.hanbit.co.kr/support/notice_list.html\"><strong>공지사항</strong></a> >\n",
      "    </span>\n",
      "              <a href=\"/support/notice_view.html?hnb_idx=300\">[채용공고]  IT 관련 도서를 함께 만들어나갈 인턴을 모십니다.</a>\n",
      "            </div>\n",
      "  <!-- //공지사항 -->\n",
      "  \n",
      "  <div class=\"foot_contents\">\n",
      "    <!-- 하단 메뉴 -->\n",
      "    <div class=\"foot_menu\">\n",
      "      <!-- added by coffin -->\n",
      "            <ul>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/publisher/index.html\" target=\"_blank\">회사소개</a>(<a href=\"https://www.hanbit.co.kr/publisher/index.html\" target=\"_blank\">KOR</a> | <a href=\"https://www.hanbit.co.kr/publisher/index.html?lang=e\" target=\"_blank\">ENG</a>) &#149; <a href=\"https://www.hanbit.co.kr/publisher/contact.html?lang=k\" target=\"_blank\">약도</a></li>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/publisher/write.html\" target=\"_blank\">기획 및 원고 모집</a></li>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/publisher/foreignrights.html\" target=\"_blank\">FOREIGN RIGHTS</a></li>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/member/use_agreement.html\">이용약관</a></li>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/member/privacy_policy.html\"><strong>개인정보취급방침</strong></a></li>\n",
      "        <li><a href=\"https://www.hanbit.co.kr/sitemap/sitemap.html\">사이트맵</a></li>\n",
      "      </ul>\n",
      "          </div>\n",
      "    <!-- //하단 메뉴 -->\n",
      "\n",
      "    <!-- SNS -->\n",
      "    <div class=\"foot_sns\">\n",
      "            \n",
      "      <ul>\n",
      "        <li class=\"foot_facebook\"><a href=\"https://www.facebook.com/hanbitmedia\" target=\"_blank\"><span>페이스북</span></a></li>\n",
      "        <!-- <li class=\"foot_googleplus\"><a href=\"https://plus.google.com/u/0/+HanbitCoKr/posts\" target=\"_blank\"><span>구글플러스</span></a></li> -->\n",
      "        <li class=\"foot_twitter\"><a href=\"https://twitter.com/hanbit\" target=\"_blank\"><span>트위터</span></a></li>\n",
      "        <li class=\"foot_youtube\"><a href=\"https://www.youtube.com/user/HanbitMedia93\" target=\"_blank\"><span>유튜브</span></a></li>\n",
      "        <li class=\"foot_bolg\"><a href=\"http://blog.hanbit.co.kr/\" target=\"_blank\"><span>블로그</span></a></li>\n",
      "        <li class=\"foot_naverpost\"><a href=\"https://m.post.naver.com/hanbitstory\" target=\"_blank\"><span>네이버포스트</span></a></li>\n",
      "      </ul>\n",
      "      \n",
      "      \n",
      "        <fieldset class=\"foot_srch\">\n",
      "          <legend>하단 검색영역</legend>\n",
      "          <input title=\"검색어\" class=\"foot_srch_keyword\" accesskey=\"s\" type=\"text\" value=\"\"  id=\"foot_keyword_str\" style=\"font-size:16px;\">\n",
      "          <input type=\"button\" alt=\"\" class=\"foot_srch_btn\" onclick=\"foot_sch_smit();\" style=\"cursor: pointer;\">\n",
      "        </fieldset>\n",
      "\n",
      "      \n",
      "      <script>\n",
      "        // 검색 리스트  \n",
      "        $(document).ready(function() {       \n",
      "          $('#foot_keyword_str').keyup(function(e) {\n",
      "            if (e.keyCode == 13) \n",
      "              foot_sch_smit();\n",
      "          });        \n",
      "        });\n",
      "\n",
      "        function foot_sch_smit(){            \n",
      "          var foot_keyword_str = $(\"#foot_keyword_str\").val();      \n",
      "          var searchUrl = \"/search/search_list.html?keyword=\"+foot_keyword_str;\n",
      "\n",
      "          if(!foot_keyword_str){\n",
      "            alert(\"검색어를 입력해주세요\");\n",
      "            $(\"#foot_keyword_str\").focus();\n",
      "          }else{\n",
      "            location.href = searchUrl;\n",
      "          }\n",
      "        }\n",
      "      </script>  \n",
      "      \n",
      "    </div>\n",
      "    <!-- //SNS -->\n",
      "    \n",
      "    <!-- 한빛 정보 -->\n",
      "    <div class=\"foot_about\">\n",
      "      <div class=\"foot_about_area\">\n",
      "        \n",
      "\n",
      "        <p><strong>한빛미디어㈜ &#149; 한빛아카데미㈜ &#149; 한빛비즈㈜</strong></p>\n",
      "        <p>(03785) 서울 서대문구 연희로2길 62</p>\n",
      "        <p>EMAIL : support@hanbit.co.kr</p>\n",
      "        <p>대표이사 : 김태헌</p>\n",
      "        <p>사업자등록번호 : 220-81-05665 <a href=\"http://www.ftc.go.kr/bizCommPop.do?wrkr_no=2208105665\" target=\"_blank\">[확인]</a></p>\n",
      "        <p>통신판매업신고 : 2017-서울서대문-0671호</p>\n",
      "        <p>호스팅제공자 : (주)누리호스팅</p>\n",
      "        \n",
      "\n",
      "      </div>\n",
      "    </div>\n",
      "    <!-- //한빛 정보 -->\n",
      "  </div>\n",
      "  \n",
      "  <div class=\"copyright\">&copy;1993-2020 Hanbit Publishing Network, Inc. All rights reserved.</div>\n",
      "</footer>\n",
      "<!-- //푸터 -->\n",
      "<div class=\"foot_download_btn\"><a href=\"https://www.hanbit.co.kr/support/supplement_list.html\">자료실</a></div>\n",
      "\n",
      "<!-- 공통 JS 호출 -->\n",
      "<script type=\"text/javascript\" src=\"/js/common.js\"></script>\n",
      "<!-- //공통 JS 호출 -->\n",
      "\n",
      "</body>\n",
      "</html>\n",
      "\n"
     ]
    }
   ],
   "source": [
    "# 추출한 인코딩으로 다시 디코딩\n",
    "text = bytes_content.decode(encoding)\n",
    "# 응답 본문을 표준 출력에 출력\n",
    "print(text)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.8"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
